@@ -1056,11 +1056,11 @@ static void print_stream_stat(pjmedia_stream *stream,
            good_number(ipbytes, sizeof(ipbytes), stat.tx.bytes + stat.tx.pkt * 32),
            "",
            stat.tx.loss,
-           stat.tx.loss * 100.0 / (stat.tx.pkt + stat.tx.loss),
+           stat.tx.loss * 100.0 / (stat.tx.pkt),
            stat.tx.dup, 
-           stat.tx.dup * 100.0 / (stat.tx.pkt + stat.tx.loss),
+           stat.tx.dup * 100.0 / (stat.tx.pkt),
            stat.tx.reorder, 
-           stat.tx.reorder * 100.0 / (stat.tx.pkt + stat.tx.loss),
+           stat.tx.reorder * 100.0 / (stat.tx.pkt),
            "",
            stat.tx.loss_period.min / 1000.0, 
            stat.tx.loss_period.mean / 1000.0, 
